#!/usr/bin/env python
# -*- coding: utf-8 -*-

##
#  @file       gamma_corrector.py
#  @brief      This script defines the GammaCorrector class, which is used for applying gamma correction to images.
#

import cv2 as cv
import numpy as np

##
#  @class      GammaCorrector
#  @brief      A class for performing gamma correction on images.
#
class GammaCorrector:
    # ˅

    # ˄

    ##
    #  @fn        __init__(self, gamma)
    #  @brief     Constructor for GammaCorrector.
    #  @param     gamma The gamma value for correction.
    #
    def __init__(self, gamma):
        # ˅
        self.gamma = gamma
        # ˄

    ##
    #  @fn        gamma_correction(self, image)
    #  @brief     Applies gamma correction to an image.
    #  @param     image The image to be gamma corrected.
    #  @return    The gamma corrected image.
    #
    def gamma_correction(self, image):
        # ˅
        # Create a lookup table for gamma correction.
        lut = np.array([((i / 255.0) ** (1 / self.gamma)) * 255 for i in np.arange(256)]).astype(np.uint8)
        # Apply the gamma correction using OpenCV's LUT function.
        return cv.LUT(image, lut)
        # ˄

    # ˅

    # ˄
