#!/usr/bin/env python
# -*- coding: utf-8 -*-

##
#  @file       image_processor.py
#  @brief      This script defines the ImageProcessor class, which uses the ImageBlender and GammaCorrector classes to adjust and blend images.
#

import cv2 as cv
from imageBlender import ImageBlender
from gammaCorrector import GammaCorrector

##
#  @class      ImageProcessor
#  @brief      A class for processing images using gamma correction and blending.
#
class ImageProcessor:
    # ˅

    # ˄

    ##
    #  @fn        __init__(self, gamma, blend_ratio=0.21)
    #  @brief     Constructor for ImageProcessor.
    #  @param     gamma Gamma value for correction.
    #  @param     blend_ratio Blend ratio for image blending, default is 0.21.
    #
    def __init__(self, gamma, blend_ratio=0.21):
        # ˅
        self.gamma_corrector = GammaCorrector(gamma)
        self.image_blender = ImageBlender(self.gamma_corrector, blend_ratio)
        # ˄

    ##
    #  @fn        adjust_images(self, left_image_path, right_image_path)
    #  @brief     Adjusts and blends two images.
    #  @param     left_image_path Path to the left image.
    #  @param     right_image_path Path to the right image.
    #  @return    A tuple of adjusted left, adjusted right, and blended images.
    #
    def adjust_images(self, left_image_path, right_image_path):
        # ˅
        adjusted_left, adjusted_right, blended_image = self.image_blender.process_images(left_image_path, right_image_path)
        return adjusted_left, adjusted_right, blended_image
        # ˄

# Script-level code to demonstrate the use of ImageProcessor
# ...

left_image_path = 'Imageleft0.png'
right_image_path = 'Imageright0.png'

gamma_value = 1.05
processor = ImageProcessor(gamma_value)

adjusted_left, adjusted_right, blended_image = processor.adjust_images(left_image_path, right_image_path)

cv.imwrite('adjusted_left.jpg', adjusted_left)
cv.imwrite('adjusted_right.jpg', adjusted_right)
cv.imwrite('blended_image.jpg', blended_image)

cv.imshow('Adjusted Left Image', adjusted_left)
cv.imshow('Adjusted Right Image', adjusted_right)
cv.imshow('Blended Image', blended_image)
cv.waitKey(0)
cv.destroyAllWindows()
